#[non_exhaustive]pub struct FidelityRecord {
pub direction: Direction,
pub path: Vec<u8>,
pub property: Property,
}Expand description
One property that did not survive, and the entry it belonged to.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.direction: DirectionWhether the property was dropped on the way in or invented on the way out.
path: Vec<u8>The entry’s path, in the spelling the source or the image used.
property: PropertyThe property.